@@ -59,7 +59,7 @@ def get_skymodel(skymodel_fn):
             dec_deg = float(dec_src[0]) + (float(dec_src[1])/60.0) + (float(dec_src[2]
                 + '.' + dec_src[3])/3600.0)
         flux = str(sline[4])
-        fluxes.append(np.float(flux))
+        fluxes.append(float(flux))
         ra_dec = np.array([[ra_deg, dec_deg]])
         try:
             x.append(w.wcs_world2pix(ra_dec, 1)[0][0])
@@ -90,8 +90,8 @@ def guess_regular_grid(xnodes, ynodes, pixelsize=None) :
     xn_rav, yn_rav = xnodes.ravel(), ynodes.ravel()
     if pixelsize is None :
         pixelsize = derive_pixelsize(xnodes, ynodes)
-    minxn = np.int(np.min(xn_rav) / pixelsize) * pixelsize
-    minyn = np.int(np.min(yn_rav) / pixelsize) * pixelsize
+    minxn = int(np.min(xn_rav) / pixelsize) * pixelsize
+    minyn = int(np.min(yn_rav) / pixelsize) * pixelsize
     xunb, yunb = np.meshgrid(np.arange(minxn, np.max(xn_rav)+pixelsize, pixelsize),
                            np.arange(minyn, np.max(yn_rav)+pixelsize, pixelsize))
 
