@@ -20,6 +20,7 @@ import logging
 from . import _logging
 from . import tableio
 from . import operations
+from .operations_lib import normalize_ra, normalize_dec
 
 # Python 3 compatibility
 try:
@@ -680,7 +681,7 @@ class SkyModel(object):
             midRA = RA[0]
             midDec = Dec[0]
 
-        return np.array(x), np.array(y), midRA, midDec
+        return np.array(x), np.array(y), normalize_ra(midRA), normalize_dec(midDec)
 
     def getDefaultValues(self):
         """
@@ -1288,13 +1289,9 @@ class SkyModel(object):
             DecDeg = self.getColValues('Dec')
 
         flux = col.data
-        try:
-            vals = attenuate(self.beamMS, flux, RADeg, DecDeg, timeIndx=self.beamTime)
-        except Exception as e:
-            self.log.warn('{0}. No beam attenuation applied.'.format(e))
-            return col
-
+        vals = attenuate(self.beamMS, flux, RADeg, DecDeg, timeIndx=self.beamTime)
         col[:] = vals
+
         return col
 
     def _getSummedColumn(self, colName, applyBeam=False):
@@ -1485,8 +1482,8 @@ class SkyModel(object):
 
             # Fill out the columns by repeating the average value over the
             # entire group
-            RAAvgFull = np.zeros(len(self.table), dtype=np.float)
-            DecAvgFull = np.zeros(len(self.table), dtype=np.float)
+            RAAvgFull = np.zeros(len(self.table), dtype=float)
+            DecAvgFull = np.zeros(len(self.table), dtype=float)
             for i, ind in enumerate(self.table.groups.indices[1:]):
                 RAAvgFull[self.table.groups.indices[i]: ind] = RAAvg[i]
                 DecAvgFull[self.table.groups.indices[i]: ind] = DecAvg[i]
@@ -2275,7 +2272,7 @@ class SkyModel(object):
 
     def compare(self, LSM2, radius='10 arcsec', outDir='.', labelBy=None,
                 ignoreSpec=None, excludeMultiple=True, excludeByFlux=False, name1=None,
-                name2=None, format='pdf'):
+                name2=None, format='pdf', make_plots=True):
         """
         Compare two sky models.
 
@@ -2317,6 +2314,8 @@ class SkyModel(object):
             Name to use in the plots for LSM2. If None, 'Model 2' is used.
         format : str, optional
             Format of plot files.
+        make_plots : bool, optional
+            If True, the plots described above are made.
 
         Returns
         -------
@@ -2356,8 +2355,8 @@ class SkyModel(object):
         stats = operations.compare.compare(self, LSM2, radius=radius, outDir=outDir,
                                            labelBy=labelBy, ignoreSpec=ignoreSpec,
                                            excludeMultiple=excludeMultiple,
-                                           excludeByFlux=excludeByFlux,
-                                           name1=name1, name2=name2, format=format)
+                                           excludeByFlux=excludeByFlux, name1=name1,
+                                           name2=name2, format=format, make_plots=make_plots)
         return stats
 
     def plot(self, fileName=None, labelBy=None):
